"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = resolve;
exports.raw = void 0;

var _loaderUtils = _interopRequireDefault(require("loader-utils"));

var _path = _interopRequireDefault(require("path"));

var _schemaUtils = _interopRequireDefault(require("schema-utils"));

var _ImageResolver = require("./ImageResolver");

var _ImageSizeResolver = require("./ImageSizeResolver");

var _ImageWrapper = require("./ImageWrapper");

var _options = _interopRequireDefault(require("./options"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const DEFAULT_IMAGE_CLASS_PATH = require.resolve('./AdaptiveImage');

const DEFAULT_IMAGE_NAME_FORMAT = '[hash][scale].[ext]';
const DEFAULT_SCALINGS = [1, 2, 3];

function interpolateName(context, nameFormat, content, scale) {
  return _loaderUtils.default.interpolateName(context, nameFormat, {
    context: context.context,
    content
  }).replace(/\[scale\]/g, scale === 1 ? '' : "@".concat(scale, "x"));
}

async function emitAndResolveImage(context, options, file) {
  var _options$name;

  const nameFormat = (_options$name = options.name) !== null && _options$name !== void 0 ? _options$name : DEFAULT_IMAGE_NAME_FORMAT;
  let fileName = interpolateName(context, nameFormat, file.content, file.scale);

  if (file.type === 'image/webp') {
    fileName = fileName.replace(/\.png|\.jpe?g/, '.webp');
  }

  let outputPath = fileName;

  if (options.outputPath) {
    outputPath = _path.default.posix.join(options.outputPath, fileName);
  }

  let publicPath = "__webpack_public_path__ + ".concat(JSON.stringify(outputPath));

  if (options.publicPath) {
    if (typeof options.publicPath === 'function') {
      publicPath = options.publicPath(fileName, file.uri);
    } else {
      publicPath = "".concat(options.publicPath.endsWith('/') ? options.publicPath : "".concat(options.publicPath, "/")).concat(fileName);
    }

    publicPath = JSON.stringify(publicPath);
  }

  context.emitFile(outputPath, file.content, null);
  return {
    outputPath,
    publicPath,
    type: file.type,
    scale: file.scale
  };
}

async function resolve(content) {
  var _options$scalings;

  const callback = this.async(); // if (this.cacheable) this.cacheable() // TODO

  const options = _loaderUtils.default.getOptions(this);

  (0, _schemaUtils.default)(_options.default, options, {
    name: 'React Native Web Image Loader',
    baseDataPath: 'options'
  });
  const esModule = typeof options.esModule !== 'undefined' ? options.esModule : false;
  const scalings = (_options$scalings = options.scalings) !== null && _options$scalings !== void 0 ? _options$scalings : DEFAULT_SCALINGS;
  const wrapImage = (0, _ImageWrapper.createImageWrapper)(_loaderUtils.default.stringifyRequest(this, options.imageClassPath || DEFAULT_IMAGE_CLASS_PATH), esModule);

  try {
    const resolvedFiles = await (0, _ImageResolver.resolveImage)(this.resourcePath, content, scalings);
    const images = await Promise.all(resolvedFiles.map(async file => {
      return await emitAndResolveImage(this, options, file);
    })); // It is possible that we don't have @1x image so normalize using scale.

    const firstFile = resolvedFiles[0];
    const size = (0, _ImageSizeResolver.imageSize)(firstFile.content, firstFile.scale);
    const result = wrapImage(size, images);
    callback(null, result);
  } catch (e) {
    callback(e);
  }
}

const raw = true;
exports.raw = raw;
//# sourceMappingURL=index.js.map